WindowController

Struct WindowController 

pub struct WindowController {
    pub matrix: Matrix<Color>,
    pub window: Window,
    /* private fields */
}
WindowController holds the main interaction between the actual matrix holding the tiles and the minifb Window.

Fields

matrix: Matrix<Color>

Where colors to be displayed are stored.

window: Window

Provided by minifb, the device that displays the tiles.

Implementations

Source

impl WindowController

pub fn new( name: &str, dimensions: Dimensions, scale: Scale, wrapping: bool, ) -> Self

Creates a new WindowController with intended matrix width and height. The scale is only initial scale when the Window is created. It may be rescaled. The Window is set with target 60fps.

pub fn update(&mut self) -> Result<(), Error>

Update Window buffer every frame wanted.

pub fn update_buffer( &mut self, buffer: impl Iterator<Item = Color>, ) -> Result<(), Error>

pub fn update_with_entities( &mut self, entities: &mut [impl Entity], ) -> Result<(), Error>

Updates window buffer each frame called and adds entities.