pub struct WindowController {
pub matrix: Matrix<Color>,
pub window: Window,
/* private fields */
}Expand description
WindowController holds the main interaction between the actual matrix holding the tiles and the minifb Window.
Fields
matrix: Matrix<Color>Where colors to be displayed are stored.
window: WindowProvided by minifb, the device that displays the tiles.
Implementations
Sourceimpl WindowController
impl WindowController
Sourcepub fn new(
name: &str,
dimensions: Dimensions,
scale: Scale,
wrapping: bool,
) -> Self
pub fn new( name: &str, dimensions: Dimensions, scale: Scale, wrapping: bool, ) -> Self
Creates a new WindowController with intended matrix width and height. The scale is only initial scale when the Window is created. It may be rescaled. The Window is set with target 60fps.
pub fn update_buffer( &mut self, buffer: impl Iterator<Item = Color>, ) -> Result<(), Error>